Creates a clinical description using LLM

createClinicalDescription(
  condition,
  llmClient,
  excludedConditions = NULL,
  outputToWord = TRUE,
  wordFileName = NULL
)

Arguments

condition

name of the clinical condition to describe

llmClient

connection object for the LLM client (see ellmer package for object details)

excludedConditions

list of excluded conditions (the clinical description will cite these)

outputToWord

write output to a Word document T or F

wordFileName

name of the Word file to create when `outputToWord = TRUE`

Value

Invisibly returns the clinical description as a text string.

Details

This function will create a concept set starting from a clinical condition and a concept id