Fetch data for concept set condensation

fetchCondenserConceptSetData(
  conceptSetExpression,
  connectionDetails = NULL,
  connection = NULL,
  cdmDatabaseSchema,
  tempEmulationSchema = getOption("sqlRenderTempEmulationSchema"),
  excludedVocabularies = c("ICDO3")
)

Arguments

conceptSetExpression

The concept set expression to condense. This can be either a JSON expression or the output of `ROhdsiWebApi::getConceptSetDefinition`.

connectionDetails

The output of `DatabaseConnector::createConnectionDetails()`. Is ignored if `connection` is provided.

connection

A `DatabaseConnector` connection. Can be NULL if `connectionDetails` is provided.

cdmDatabaseSchema

A database schema holding the OHDSI Vocabulary tables.

tempEmulationSchema

For database platforms that do not natively support temp tables, a database schema where the user has write access.

excludedVocabularies

Vocabularies not to be included in the condensing function

Value

A list containing the three inputs for `condenseConceptSet()`.