Creates a clinical description using LLM
createClinicalDescription(
condition,
llmClient,
excludedConditions = NULL,
outputToWord = TRUE,
wordFileName = NULL
)name of the clinical condition to describe
connection object for the LLM client (see ellmer package for object details)
list of excluded conditions (the clinical description will cite these)
write output to a Word document T or F
name of the Word file to create when `outputToWord = TRUE`
Invisibly returns the clinical description as a text string.
This function will create a concept set starting from a clinical condition and a concept id