R/CondenserDataFetch.R
fetchCondenserConceptSetData.RdFetch data for concept set condensation
The concept set expression to condense. This can be either a JSON expression or the output of `ROhdsiWebApi::getConceptSetDefinition`.
The output of `DatabaseConnector::createConnectionDetails()`. Is ignored if `connection` is provided.
A `DatabaseConnector` connection. Can be NULL if `connectionDetails` is provided.
A database schema holding the OHDSI Vocabulary tables.
For database platforms that do not natively support temp tables, a database schema where the user has write access.
Vocabularies not to be included in the condensing function
A list containing the three inputs for `condenseConceptSet()`.